EventElement class abstract Submodel elements

An event element.

Inheritance
Implementers

Constructors

EventElement({List<ModelExtension>? extensions, String? category, ReferableAllOfIdShort? idShort, List<LangStringNameType>? displayName, List<LangStringTextType>? description, required ModelType modelType, Reference? semanticId, List<Reference>? supplementalSemanticIds, List<Qualifier>? qualifiers, List<EmbeddedDataSpecification>? embeddedDataSpecifications})
Returns a new EventElement instance.

Properties

category String?
The category is a value that gives further meta information w.r.t. the class of the element. It affects the expected existence of attributes and the applicability of constraints
getter/setter pairinherited
description List<LangStringTextType>
Description or comments on the element.
getter/setter pairinherited
displayName List<LangStringNameType>
Display name. Can be provided in several languages.
getter/setter pairinherited
embeddedDataSpecifications List<EmbeddedDataSpecification>
Global reference to the data specification template used by the element.
getter/setter pairinherited
extensions List<ModelExtension>
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
idShort ReferableAllOfIdShort?
In case of identifiables this attribute is a short name of the element. In case of referable this ID is an identifying string of the element within its name space.
getter/setter pairinherited
kind ModellingKind?
Kind of the element: either type or instance.
getter/setter pairinherited
modelType ModelType
getter/setter pairinherited
qualifiers List<Qualifier>
Additional qualification of a qualifiable element.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticId Reference?
Identifier of the semantic definition of the element. It is called semantic ID or also main semantic ID of the element.
getter/setter pairinherited
supplementalSemanticIds List<Reference>
Identifier of a supplemental semantic definition of the element. It is called supplemental semantic ID of the element.
getter/setter pairinherited

Methods

copy() SubmodelElement
Creates a new SubmodelElement from this one.
inherited
getDesignation({String? localeCode}) String
Determine a display name based on information in this widget.
inherited
getModelReferenceKey() Key?
If this SmE has a idShort construct an appropriate key.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize this object to a json representation.
inherited
toMap() Map<String, dynamic>
Create a map with all attributes names as keys and the attribute values as primitives(int, List, Map, String, ...) or Serializable.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.