HasExtensions class abstract

Mixed-in types
Implementers

Constructors

HasExtensions({List<ModelExtension>? extensions})
Returns a new HasExtensions instance.

Properties

extensions List<ModelExtension>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize this object to a json representation.
inherited
toMap() Map<String, dynamic>
Create a map with all attributes names as keys and the attribute values as primitives(int, List, Map, String, ...) or Serializable.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

jsonKeyExtensions → const String
requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.