Referable class abstract

Inheritance
Implementers

Constructors

Referable({List<ModelExtension>? extensions, String? category, ReferableAllOfIdShort? idShort, List<LangStringNameType>? displayName, List<LangStringTextType>? description, required ModelType modelType})
Returns a new Referable instance.

Properties

category String?
The category is a value that gives further meta information w.r.t. the class of the element. It affects the expected existence of attributes and the applicability of constraints
getter/setter pair
description List<LangStringTextType>
Description or comments on the element.
getter/setter pair
displayName List<LangStringNameType>
Display name. Can be provided in several languages.
getter/setter pair
extensions List<ModelExtension>
getter/setter pairinherited
hashCode int
The hash code for this object.
no setteroverride
idShort ReferableAllOfIdShort?
In case of identifiables this attribute is a short name of the element. In case of referable this ID is an identifying string of the element within its name space.
getter/setter pair
modelType ModelType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDesignation({String? localeCode}) String
Determine a display name based on information in this widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize this object to a json representation.
inherited
toMap() Map<String, dynamic>
Create a map with all attributes names as keys and the attribute values as primitives(int, List, Map, String, ...) or Serializable.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

jsonKeyCategory → const String
jsonKeyDescription → const String
jsonKeyDisplayName → const String
jsonKeyIdShort → const String
jsonKeyModelType → const String
requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.