API Clients topic

API clients provide a method based interface for interacting with HTTP endpoints.

Most clients will require an ApiClient object that will be used to perform all requests. This is necessary to provide the remotes URL and authenticate requests.

Under the hood API client methods insert simple arguments in their respective position as URL path parameters and convert more complex objects to json and insert them as the request body. The responses status code is used to detect a request failure in which case it throws an ApiException. Responses indicating success are deserialized from json to their corresponding dart object and returned.

Classes

AASXFileServerAPIApi API Clients
Client for servers implementing the AASX File Server Service Specification.
AssetAdministrationShellAPIApi API Clients
Client for servers implementing the Asset Administration Shell Interface.
AssetAdministrationShellBasicDiscoveryAPIApi API Clients
These interfaces allow to publish information about Asset Administration Shells that enable a search for asset IDs of the corresponding Asset Administration Shells in a subsequent discovery interface call.
AssetAdministrationShellRegistryAPIApi API Clients
Client for servers implementing the [Asset Administration Shell Registry Service Specification(https://app.swaggerhub.com/apis/Plattform_i40/AssetAdministrationShellRegistryServiceSpecification/V3.0_SSP-001).
AssetAdministrationShellRepositoryAPIApi API Clients
The AAS Repository is a component that provides a REST API to interact with Asset Administration Shells. It allows the creation, retrieval, update, and deletion of AAS instances.
AsyncBulkAssetAdministrationShellRegistryAPIApi API Clients
AsyncBulkSubmodelRegistryAPIApi API Clients
ConceptDescriptionRepositoryAPIApi API Clients
The ConceptDescription Repository is a component that provides a REST API to interact with ConceptDescriptions. It allows the creation, retrieval, update, and deletion of ConceptDescriptions.
DescriptionAPIApi API Clients
SerializationAPIApi API Clients
SubmodelAPIApi API Clients
SubmodelRegistryAPIApi API Clients
SubmodelRepositoryAPIApi API Clients