Submodel elements topic

Submodel element are qualifiable elements, i.e. one or more qualifiers may be defined for each of them.

Submodel elements may also have data specification templates defined for them. A template might for example be defined to mirror some of the attributes like preferredName and unit of a property concept definition if there is no corresponding concept description available. Otherwise, there only is the property definition referenced by semanticId available for the property: the lookup of the attributes has to be realized online in a different way and is not available offline.

In case the submodel is of kind=Template then the submodel elements within the submodel are presenting submodel element types. In case the submodel is of kind=Instance then its submodel elements represent submodel element instances.

Classes

Blob Submodel elements
A BLOB is a data element that represents a file that is contained with its source code in the value attribute
Capability Submodel elements
A capability is the implementation-independent description of the potential of an asset to achieve a certain effect in the physical or virtual world.
DataElement Submodel elements
A data element is a submodel element that is not further composed out of other submodel elements.
DataSpecificationIec61360 Submodel elements
Content of data specification template for concept descriptions for properties, values, and value lists conformant to IEC 61360.
Entity Submodel elements
An entity is a submodel element that is used to model entities.
EventElement Submodel elements
An event element.
File Submodel elements
A File is a data element that represents an address to a file (a locator).
MultiLanguageProperty Submodel elements
A property is a data element that has a multi-language value.
Operation Submodel elements
An operation is a submodel element with input and output variables.
Property<T> Submodel elements
A property is a data element that has a single value.
Range Submodel elements
A range data element is a data element that defines a range with min and max
ReferenceElement Submodel elements
A reference element is a data element that defines a logical reference to another element within the same or another AAS or a reference to an external object or entity.
RelationshipElement Submodel elements
A relationship element is used to define a relationship between two elements being either referable (model reference) or external (global reference).
SubmodelElementCollection Submodel elements
A submodel element collection is a kind of struct, i.e. a logical encapsulation of multiple named values.
SubmodelElementList Submodel elements
A submodel element list is an ordered list of submodel elements.