LangStringTextType class
String with length 1023 maximum and minimum 1 characters and with language tags.
- Inheritance
-
- Object
- AbstractLangString
- LangStringTextType
Constructors
- LangStringTextType({required String language, required String text})
- Returns a new LangStringTextType instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- language ↔ String
-
Language tag conforming to BCP 47.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
Text in the AbstractLangString.language.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this object to a json representation.
inherited
-
toMap(
) → Map< String, dynamic> -
Create a map with all attributes names as keys and the attribute values
as primitives(int, List, Map, String, ...) or Serializable.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → LangStringTextType? -
Returns a new LangStringTextType instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = true}) → List< LangStringTextType> -
If
jsonis a List this function attempts to convert all non-null items using toJson. Returns null ifjsonis null. -
mapFromJson(
dynamic json) → Map< String, LangStringTextType> -
If
jsonis a Map this function attempts to convert all non-null values using toJson and maintains key relation. Returns null otherwise.
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.