ModelExtension class
- Mixed-in types
Constructors
-
ModelExtension({Reference? semanticId, List<
Reference> ? supplementalSemanticIds, required String name, DataTypeDefXsd? valueType = DataTypeDefXsd.string, XsdValue? value, List<Reference> ? refersTo}) - Returns a new ModelExtension instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
Name of the extension.
getter/setter pair
-
refersTo
↔ List<
Reference> -
Reference to an element the extension refers to.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticId ↔ Reference?
-
getter/setter pair
-
supplementalSemanticIds
↔ List<
Reference> -
getter/setter pair
- value ↔ XsdValue?
-
Value of the extension.
getter/setter pair
- valueType ↔ DataTypeDefXsd?
-
Type of the value of the extension.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this object to a json representation.
inherited
-
toMap(
) → Map< String, dynamic> -
Create a map with all attributes names as keys and the attribute values
as primitives(int, List, Map, String, ...) or Serializable.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ModelExtension? -
Returns a new ModelExtension instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = true}) → List< ModelExtension> -
If
jsonis a List this function attempts to convert all non-null items using toJson. Returns null ifjsonis null. -
mapFromJson(
dynamic json) → Map< String, ModelExtension> -
If
jsonis a Map this function attempts to convert all non-null values using toJson and maintains key relation. Returns null otherwise.
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.