SubmodelElement class abstract
A submodel element is an element suitable for the description and differentiation of assets.
It is recommended to add a semanticId to a [SubmodelElement}.
- Inheritance
-
- Object
- HasExtensions
- Referable
- SubmodelElement
- Implemented types
- Implementers
Constructors
-
SubmodelElement({List<
ModelExtension> ? extensions, String? category, ReferableAllOfIdShort? idShort, List<LangStringNameType> ? displayName, List<LangStringTextType> ? description, required ModelType modelType, ModellingKind? kind, Reference? semanticId, List<Reference> ? supplementalSemanticIds, List<Qualifier> ? qualifiers, List<EmbeddedDataSpecification> ? embeddedDataSpecifications})
Properties
- category ↔ String?
-
The category is a value that gives further meta information
w.r.t. the class of the element. It affects the expected
existence of attributes and the applicability of constraints
getter/setter pairinherited
-
description
↔ List<
LangStringTextType> -
Description or comments on the element.
getter/setter pairinherited
-
displayName
↔ List<
LangStringNameType> -
Display name. Can be provided in several languages.
getter/setter pairinherited
-
embeddedDataSpecifications
↔ List<
EmbeddedDataSpecification> -
Global reference to the data specification template used by the element.
getter/setter pairoverride
-
extensions
↔ List<
ModelExtension> -
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- idShort ↔ ReferableAllOfIdShort?
-
In case of identifiables this attribute is a short name of the
element. In case of referable this ID is an identifying string
of the element within its name space.
getter/setter pairinherited
- kind ↔ ModellingKind?
-
Kind of the element: either type or instance.
getter/setter pairoverride
- modelType ↔ ModelType
-
getter/setter pairinherited
-
qualifiers
↔ List<
Qualifier> -
Additional qualification of a qualifiable element.
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticId ↔ Reference?
-
Identifier of the semantic definition of the element. It is called
semantic ID or also main semantic ID of the element.
getter/setter pairoverride
-
supplementalSemanticIds
↔ List<
Reference> -
Identifier of a supplemental semantic definition of the element. It is
called supplemental semantic ID of the element.
getter/setter pairoverride
Methods
-
copy(
) → SubmodelElement - Creates a new SubmodelElement from this one.
-
getDesignation(
{String? localeCode}) → String -
Determine a display name based on information in this widget.
inherited
-
getModelReferenceKey(
) → Key? - If this SmE has a idShort construct an appropriate key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialize this object to a json representation.
inherited
-
toMap(
) → Map< String, dynamic> -
Create a map with all attributes names as keys and the attribute values
as primitives(int, List, Map, String, ...) or Serializable.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SubmodelElement? -
Returns a new SubmodelElement instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = true}) → List< SubmodelElement> -
If
jsonis a List this function attempts to convert all non-null items using toJson. Returns null ifjsonis null. -
mapFromJson(
dynamic json) → Map< String, SubmodelElement> -
If
jsonis a Map this function attempts to convert all non-null values using toJson and maintains key relation. Returns null otherwise.
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.